[![codecov](https://codecov.io/gh/selfcustody/urtypes/branch/main/graph/badge.svg?token=LMJZ29IHSB)](https://codecov.io/gh/selfcustody/urtypes)

# urtypes

Python implementation of the [Blockchain Commons UR Types specification](https://github.com/BlockchainCommons/Research/blob/master/papers/bcr-2020-006-urtypes.md)